@@ -1,3 +1,4 @@
 import subprocess as sp
-from mport search_that_hash.cracker.offline_mod import hashcat
+from search_that_hash.cracker.offline_mod import hashcat
+
 # Make a class here that calls both depending on the data provided
